@@ -2,6 +2,7 @@ from hashlib import pbkdf2_hmac
 
 from Crypto import Random
 from Crypto.Cipher import AES
+import binascii
 
 ITERATIONS = 1000
 KEY_LENGTH = 32
@@ -25,9 +26,10 @@ class Crypt(object):
     def encrypt(self, data, salt):
         aes = AES.new(self._derive_key(salt), AES.MODE_CBC,
                       generate_iv())
-        return aes.IV.encode('hex'), aes.encrypt(pad(data.decode('hex'))).encode('hex')
+        binary = binascii.unhexlify(data)
+        return binascii.hexlify(aes.IV), binascii.hexlify(aes.encrypt(pad(binary)))
 
     def decrypt(self, encrypted, salt, iv):
         encrypted, salt, iv = str(encrypted), str(salt), str(iv)
         aes = AES.new(self._derive_key(salt), AES.MODE_CBC, iv.decode('hex'))
-        return unpad(aes.decrypt(encrypted.decode('hex'))).encode('hex')
+        return binascii.hexlify(unpad(aes.decrypt(binascii.unhexlify(encrypted))))
